@@ -1,7 +1,7 @@
 /**
  * gui.c - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2011 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  * 
@@ -28,6 +28,9 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <stdlib.h>
+#include <glib/gi18n.h>
+
+#include <locale.h>
 
 #include "clicked_node.h"
 
@@ -108,51 +111,51 @@ gchar *window_saved_title=NULL;
 
 static GtkActionEntry sMenuActions[] = 
 {
-	{ "FileMenuAction", NULL, "_File" },
-	{ "EditMenuAction", NULL, "_Edit" },
-	{ "ViewMenuAction", NULL, "_View" },
-	{ "HelpMenuAction", NULL, "_Help" },
+	{ "FileMenuAction", NULL, N_("_File") },
+	{ "EditMenuAction", NULL, N_("_Edit") },
+	{ "ViewMenuAction", NULL, N_("_View") },
+	{ "HelpMenuAction", NULL, N_("_Help") },
 	
-	{ "OpenProjectAction", GTK_STOCK_OPEN, "_Open Project", "<control>O", "Open Project", G_CALLBACK(openproject_menu_cb) },
-	{ "SaveProjectAction", GTK_STOCK_SAVE, "_Save Project", "<control>S", "Save Project", G_CALLBACK(saveproject_menu_cb) },
-	{ "SaveProjectAsAction", GTK_STOCK_SAVE_AS, "Save Project As...", "<control><shift>S", "Save Proeject As", G_CALLBACK(saveproject_as_menu_cb) },
-	{ "ExitAction", GTK_STOCK_QUIT, "_Exit", "<control>Q", "Exit", G_CALLBACK(quit_menu_cb) },
+	{ "OpenProjectAction", GTK_STOCK_OPEN, NC_("File|","_Open project"), "<control>O", N_("Open Project"), G_CALLBACK(openproject_menu_cb) },
+	{ "SaveProjectAction", GTK_STOCK_SAVE, NC_("File|","_Save project"), "<control>S", N_("Save Project"), G_CALLBACK(saveproject_menu_cb) },
+	{ "SaveProjectAsAction", GTK_STOCK_SAVE_AS, NC_("File|","Save project as..."), "<control><shift>S", N_("Save Project with a specific filename"), G_CALLBACK(saveproject_as_menu_cb) },
+	{ "ExitAction", GTK_STOCK_QUIT, NC_("File|","_Exit"), "<control>Q", N_("Exit"), G_CALLBACK(quit_menu_cb) },
 	
-	{ "CreateGroupAction", GTK_STOCK_DIRECTORY, "Create _Group", "", "Create a group node in the project", G_CALLBACK(creategroup_menu_cb) },
-	{ "AddFileAction", GTK_STOCK_FILE, "Add _File", "", "Add a file to the project", G_CALLBACK(addfile_menu_cb) },
-	{ "RemoveFileAction", GTK_STOCK_DELETE, "Remove File(s)", "", "Remove selected files from the project", G_CALLBACK(removeitem_menu_cb) },
+	{ "CreateGroupAction", GTK_STOCK_DIRECTORY, NC_("Edit|","Create _group"), "", N_("Create a new group in the project"), G_CALLBACK(creategroup_menu_cb) },
+	{ "AddFileAction", GTK_STOCK_FILE, NC_("Edit|","Add _file"), "", N_("Add a file to the project"), G_CALLBACK(addfile_menu_cb) },
+	{ "RemoveFileAction", GTK_STOCK_DELETE, NC_("Edit|","Remove file(s)"), "", N_("Remove selected files from the project"), G_CALLBACK(removeitem_menu_cb) },
 	
-	{ "ExpandAllGroupsAction", NULL, "Expand All Groups", "<control><shift>E", "Expand All Groups", G_CALLBACK(expand_all_items_cb) },
-	{ "CollapseAllGroupsAction", NULL, "Collapse All Groups", "<control><shift>C", "Collapse All Groups", G_CALLBACK(collapse_all_items_cb) },
+	{ "ExpandAllGroupsAction", NULL, NC_("Edit|","Expand all groups"), "<control><shift>E", N_("Expand All Groups"), G_CALLBACK(expand_all_items_cb) },
+	{ "CollapseAllGroupsAction", NULL, NC_("Edit|","Collapse all groups"), "<control><shift>C", N_("Collapse All Groups"), G_CALLBACK(collapse_all_items_cb) },
 	
-	{ "SearchAction", GTK_STOCK_FIND, "Search", "<control>F", "Search for a string in the project", G_CALLBACK(search_dialog_cb) },
+	{ "SearchAction", GTK_STOCK_FIND, NC_("Edit|","Search"), "<control>F", N_("Search for a string in the project"), G_CALLBACK(search_dialog_cb) },
 	
-	{ "AboutAction", GTK_STOCK_ABOUT, "_About", "", "Show information about this application", G_CALLBACK(about_menu_cb) },
+	{ "AboutAction", GTK_STOCK_ABOUT, NC_("Help|","_About"), "", N_("Show information about this application"), G_CALLBACK(about_menu_cb) },
 	
-	{ "AddFilesPopupAction", GTK_STOCK_FILE, "Add Files", "", "Add files to the project", G_CALLBACK(popup_add_files_cb) },
-	{ "AddGroupPopupAction", GTK_STOCK_DIRECTORY, "Add Group", "", "Add a group to the project", G_CALLBACK(popup_add_group_cb) },
+	{ "AddFilesPopupAction", GTK_STOCK_FILE, N_("Add files"), "", N_("Add files to the project"), G_CALLBACK(popup_add_files_cb) },
+	{ "AddGroupPopupAction", GTK_STOCK_DIRECTORY, N_("Create _group"), "", N_("Create a new group in the project"), G_CALLBACK(popup_add_group_cb) },
 	
-	{ "AddFilestoGroupPopupAction", GTK_STOCK_FILE, "Add Files to Group", "", "Add files to an existing group", G_CALLBACK(popup_add_files_cb) },
-	{ "AddSubgroupPopupAction", GTK_STOCK_DIRECTORY, "Add Subgroup to Group", "", "Add a subgroup to an existing group", G_CALLBACK(popup_add_group_cb) },
-	{ "RenameGroupPopupAction", GTK_STOCK_EDIT, "Rename Group", "", "Rename a group", G_CALLBACK(popup_rename_group_cb) },
-	{ "RemoveGroupPopupAction", GTK_STOCK_DELETE, "Remove Group From Project", "", "Remove a group and its children from the project", G_CALLBACK(popup_remove_node_cb) },
-	{ "SortAscendingAction", GTK_STOCK_SORT_ASCENDING, "Sort Group Ascending","","Sort the filenames ascending",G_CALLBACK(sort_ascending_cb) },
-	{ "SortDescendingAction", GTK_STOCK_SORT_DESCENDING, "Sort Group Descending","","Sort the filenames descending",G_CALLBACK(sort_descending_cb) },
-	{ "PropertiesGroupPopupAction", GTK_STOCK_PROPERTIES, "Group Properties", "", "Show group properties", G_CALLBACK(group_properties_cb) },
-	{ "EditOptionsAction", GTK_STOCK_PROPERTIES, "Edit Options", "", "Edit Program Options", G_CALLBACK(edit_options_cb) },
+	{ "AddFilestoGroupPopupAction", GTK_STOCK_FILE, N_("Add files to group"), "", N_("Add files to an existing group"), G_CALLBACK(popup_add_files_cb) },
+	{ "AddSubgroupPopupAction", GTK_STOCK_DIRECTORY, N_("Add subgroup to group"), "", N_("Add a subgroup to an existing group"), G_CALLBACK(popup_add_group_cb) },
+	{ "RenameGroupPopupAction", GTK_STOCK_EDIT, N_("Rename group"), "", N_("Rename a group"), G_CALLBACK(popup_rename_group_cb) },
+	{ "RemoveGroupPopupAction", GTK_STOCK_DELETE, N_("Remove group from project"), "", N_("Remove a group and its children from the project"), G_CALLBACK(popup_remove_node_cb) },
+	{ "SortAscendingAction", GTK_STOCK_SORT_ASCENDING, N_("Sort group ascending"),"",N_("Sort the filenames ascending"),G_CALLBACK(sort_ascending_cb) },
+	{ "SortDescendingAction", GTK_STOCK_SORT_DESCENDING, N_("Sort group descending"),"",N_("Sort the filenames descending"),G_CALLBACK(sort_descending_cb) },
+	{ "PropertiesGroupPopupAction", GTK_STOCK_PROPERTIES, NC_("RightClickGroupPopup","Properties"), "", N_("Show group properties"), G_CALLBACK(group_properties_cb) },
+	{ "EditOptionsAction", GTK_STOCK_PROPERTIES, NC_("Edit|","Edit options"), "", N_("Edit program options"), G_CALLBACK(edit_options_cb) },
 	
-	{ "ViewRecentAction" , GTK_STOCK_PROPERTIES, "View Recently Opened Files", "<control>R", "View Recent Files", G_CALLBACK(recent_files_switch_visible) },
+	{ "ViewRecentAction" , GTK_STOCK_PROPERTIES, NC_("View|","View recently opened files"), "<control>R", N_("View Recent Files"), G_CALLBACK(recent_files_switch_visible) },
 	
-	{ "OpenFilePopupAction", GTK_STOCK_OPEN, "Open File in SciTE", "", "Open a file in SciTE", G_CALLBACK(popup_open_file_cb) },
-	{ "RemoveFilePopupAction", GTK_STOCK_DELETE, "Remove File From Project", "", "Remove a file from the project", G_CALLBACK(popup_remove_node_cb) },
-	{ "CopyFilenameToClipBoardAction", GTK_STOCK_COPY, "Copy Filename to Clipboard", "", "Copies the full path and filename to the clipboard", G_CALLBACK(copy_filename_to_clipboard_cb) },
-	{ "PropertiesPopupAction", GTK_STOCK_PROPERTIES, "File Properties", "", "Show file properties", G_CALLBACK(file_properties_cb) },
+	{ "OpenFilePopupAction", GTK_STOCK_OPEN, N_("Open file in SciTE"), "", N_("Open a file in SciTE"), G_CALLBACK(popup_open_file_cb) },
+	{ "RemoveFilePopupAction", GTK_STOCK_DELETE, N_("Remove file From project"), "", N_("Remove a file from the project"), G_CALLBACK(popup_remove_node_cb) },
+	{ "CopyFilenameToClipBoardAction", GTK_STOCK_COPY, N_("Copy filename to clipboard"), "", N_("Copies the full path and filename to the clipboard"), G_CALLBACK(copy_filename_to_clipboard_cb) },
+	{ "PropertiesPopupAction", GTK_STOCK_PROPERTIES, NC_("RightClickFilePopup","Properties"), "", N_("Show file properties"), G_CALLBACK(file_properties_cb) },
 	
-	{ "OpenRecentFilePopupAction", GTK_STOCK_OPEN, "Open File in SciTE", "", "Open a file in SciTE", G_CALLBACK(popup_open_recent_file_cb) },
-	{ "RemoveRecentFilePopupAction", GTK_STOCK_DELETE, "Remove File from this List", "", "Remove file from this List", G_CALLBACK(popup_remove_recent_file_cb) },
-	{ "CopyRecentToClipboardAction", GTK_STOCK_COPY, "Copy filename to clipboard", "", "Copy filename to clipboard", G_CALLBACK(copy_recent_filename_to_clipboard_cb) },
+	{ "OpenRecentFilePopupAction", GTK_STOCK_OPEN, N_("Open file in SciTE"), "", N_("Open a file in SciTE"), G_CALLBACK(popup_open_recent_file_cb) },
+	{ "RemoveRecentFilePopupAction", GTK_STOCK_DELETE, N_("Remove file from this list"), "", N_("Remove file from this List"), G_CALLBACK(popup_remove_recent_file_cb) },
+	{ "CopyRecentToClipboardAction", GTK_STOCK_COPY, N_("Copy filename to clipboard"), "", N_("Copy filename to clipboard"), G_CALLBACK(copy_recent_filename_to_clipboard_cb) },
 	
-	{ "PropertiesRecentPopupAction", GTK_STOCK_PROPERTIES, "File Properties", "", "Show file properties", G_CALLBACK(properties_recent_file_cb) }
+	{ "PropertiesRecentPopupAction", GTK_STOCK_PROPERTIES, NC_("RecentFilePopup","Properties"), "", N_("Show file properties"), G_CALLBACK(properties_recent_file_cb) }
 
 };
 
@@ -179,8 +182,13 @@ GtkWidget *scrolledWindow = NULL;
 
 GtkTreeViewColumn *column1 = NULL;
 
+#if GTK_MAJOR_VERSION>=3
+GtkWidget *recentGrid=NULL;
+#else
 GtkWidget *recentVbox=NULL;
+#endif
 
+GtkWidget *recentHbox=NULL;
 
 /**
  * Initialize globals (i.e. create the main window and populate it).  This is a long chunk of code.
@@ -193,34 +201,40 @@ gboolean setup_gui(GError **err)
 {
 	gboolean resultCode = FALSE;
 	GtkTreeSelection *selection = NULL;
-	GtkWidget *vbox=NULL;
-	
 	GtkWidget *vpaned=NULL;
 
 	GtkTargetEntry dragTargets[] = { { (gchar*)"text/uri-list", 0, DND_URI_TYPE } };
 	GtkTreeStore *projectTreeStore = NULL;
 	GtkAccelGroup* accelgroup = NULL;
 	GError *tempErr = NULL;
+	
+#if GTK_MAJOR_VERSION>=3
+	GtkWidget *grid;
+	GtkWidget *fullGrid=NULL;
+#else
+	GtkWidget *vbox=NULL;
+	GtkWidget *hbox=NULL;
+	
+	GtkWidget *statusBarVbox=NULL;
+	GtkWidget *fullVbox=NULL;
+#endif
 			
 	GtkWidget *recentScrolledWindow=NULL;
 	
-	GtkWidget *recentHbox=NULL;
-
-	GtkWidget *fullVbox=NULL;
 	
-	GtkWidget *hbox=NULL;
-	GtkWidget *statusBarVbox=NULL;
-		
 	clicked_node.valid=FALSE;
 	clicked_node.name=NULL;
 	clicked_node.type=-1;
 	
-	window_saved_title=g_strdup_printf("[UNTITLED]");
+	window_saved_title=g_strdup_printf(_("[UNTITLED]"));
 	
 	// Create top-level window, configure it
 	
 	if (!(sMainWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main window, gtk_window_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_window_new() = NULL", 
+			__func__,
+			"Couldn't init main window"
+		);
 		
 		goto EXITPOINT;
 	}
@@ -241,43 +255,69 @@ gboolean setup_gui(GError **err)
 	
 	// Main content of the window is a vpaned
 	
+#if GTK_MAJOR_VERSION>=3
+	vpaned=gtk_paned_new(GTK_ORIENTATION_VERTICAL);
+	
+	// Then we need a grid
+	grid=gtk_grid_new();
+
+#else
 	vpaned=gtk_vpaned_new();
-	
+
 	// Then we need a vbox
-	
+
 	if (!(vbox = gtk_vbox_new(FALSE, 0))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main vbox, gtk_vbox_new() = NULL", __func__);
-		
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_vbox_new() = NULL", 
+			__func__,
+			"Couldn't init main vbox"
+		);
 		goto EXITPOINT;
 	}
-	
+
 	//gtk_container_add(GTK_CONTAINER(sMainWindow), vbox);
 	
+#endif
 	
-	//gtk_container_add(GTK_CONTAINER(sMainWindow), recentVbox);
 	
 	// Create menus
 	
 	if (!(sActionGroup = gtk_action_group_new("SciteProjActions"))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkActionGroup, gtk_action_group_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_action_group_new() = NULL",
+			__func__,
+			"Couldn't init gtk_action_group"
+		);
 		
 		goto EXITPOINT;
 	}
 		
 	if (!(sGtkUIManager = gtk_ui_manager_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkUIManager, gtk_ui_manager_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_ui_manager_new() = NULL", 
+			__func__,
+			"Couldn't init gtk_ui_manager"
+		);
 		
 		goto EXITPOINT;
 	}
 	
+#if GTK_MAJOR_VERSION>=3
+	g_signal_connect(sGtkUIManager, "add_widget", G_CALLBACK(menu_add_widget_cb), grid);
+#else
+	//g_signal_connect(sGtkUIManager, "add_widget", G_CALLBACK(menu_add_widget_cb), vpaned);
 	g_signal_connect(sGtkUIManager, "add_widget", G_CALLBACK(menu_add_widget_cb), vbox);
+#endif 
+	
+	gtk_action_group_set_translation_domain(sActionGroup,PACKAGE);
 	
 	gtk_action_group_add_actions(sActionGroup, sMenuActions, sNumMenuActions, NULL);
 	
 	gtk_ui_manager_insert_action_group(sGtkUIManager, sActionGroup, 0);
 	
 	if (gtk_ui_manager_add_ui_from_string(sGtkUIManager, sMenuDefXML, strlen(sMenuDefXML), &tempErr) == 0) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create create menus from XML, gtk_ui_manager_add_ui_from_string() = %s", __func__, tempErr->message);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_ui_manager_add_ui_from_string() = %s",
+			__func__, 
+			"Couldn't init menus from XML",
+			tempErr->message
+		);
 		
 		goto EXITPOINT;
 	}
@@ -300,34 +340,48 @@ gboolean setup_gui(GError **err)
 	// Add a scrolled window to the main window
 	
 	if (!(scrolledWindow = gtk_scrolled_window_new(NULL, NULL))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main scrolled window, gtk_scrolled_window_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_scrolled_window_new() = NULL",
+			__func__,
+			"Couldn't init main scrolled window"
+		);
 		
 		goto EXITPOINT;
 	}
 	
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
+
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach(GTK_GRID(grid),scrolledWindow,0,1,1,1);
 	
+	gtk_widget_set_vexpand(scrolledWindow,TRUE);
+	gtk_widget_set_hexpand(scrolledWindow,TRUE);
+#else
 	gtk_box_pack_start(GTK_BOX(vbox), scrolledWindow, TRUE, TRUE, 0);
 	
-	
 	hbox=gtk_hbox_new(FALSE,0);
 	
 	gtk_widget_show(hbox);
 	
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,TRUE,0);
+#endif
 	
-
 	// Create the tree datastore
 	
 	if ((projectTreeStore = create_treestore(&tempErr)) == NULL) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create the treestore", tempErr->message);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s", 
+			tempErr->message,
+			"Couldn't init treestore"
+		);
 		goto EXITPOINT;
 	}
 		
 	// Create the treeview, set it up to render the tree datastore, and add it to the hbox
 	
 	if (!(projectTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(projectTreeStore)))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkTreeView, gtk_tree_view_new_with_model() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_tree_view_new_with_model() = NULL", 
+			__func__,
+			"Couldn't init gtk_tree_view"
+		);
 		
 		goto EXITPOINT;
 	}
@@ -337,7 +391,10 @@ gboolean setup_gui(GError **err)
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(projectTreeView),TRUE);
 	
 	if (!(textCellRenderer = gtk_cell_renderer_text_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkCellRenderer, gtk_cell_renderer_text_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_cell_renderer_text_new() = NULL", 
+			__func__,
+			"Couldn't init cell renderer"
+		);
 		
 		goto EXITPOINT;
 	}
@@ -348,13 +405,21 @@ gboolean setup_gui(GError **err)
 			NULL);
 	
 	if (!(pixbuffCellRenderer = gtk_cell_renderer_pixbuf_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkCellRenderer, gtk_cell_renderer_pixbuf_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+			"%s: %s, gtk_cell_renderer_pixbuf_new() = NULL",
+			__func__,
+			"Couldn't init gtk_cell_renderer_pixbuf"
+		);
 		
 		goto EXITPOINT;
 	}
 	
 	if (!(column1 = gtk_tree_view_column_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkTreeViewColumn, gtk_tree_view_column_new() = NULL", __func__);
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_tree_view_column_new() = NULL",
+			__func__,
+			"Couldn't init gtk_tree_view_column"
+		);
 		
 		goto EXITPOINT;
 	}
@@ -412,15 +477,37 @@ gboolean setup_gui(GError **err)
 	// --------------------------------
 	// Recent file stuff:
 	
-	if (!(recentVbox = gtk_vbox_new(FALSE, 0))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main vbox, gtk_vbox_new() = NULL", __func__);
-		
-		goto EXITPOINT;
-	}
+#if GTK_MAJOR_VERSION>=3
 	
+	if (!(recentGrid=gtk_grid_new())) {
+		g_set_error(err, APP_SCITEPROJ_ERROR,-1,
+			"%s: %s, gtk_grid_new() = NULL",
+			"Couldn't init recent grid",
+			__func__);
+		goto EXITPOINT;
+	}	
+	
+#else
+	if (!(recentVbox=gtk_vbox_new(FALSE, 0))) {
+		g_set_error(err, APP_SCITEPROJ_ERROR,-1,
+			"%s: %s, gtk_vbox_new() = NULL",
+			__func__,
+			"Couldn't init recent grid"
+			);
+		goto EXITPOINT;
+	}	
+#endif
+	
+#if GTK_MAJOR_VERSION>=3
+	if (!(recentHbox=gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0))) {
+#else
 	if (!(recentHbox=gtk_hbox_new(FALSE,0))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create main vbox, gtk_hbox_new() = NULL", __func__);
-		
+#endif
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+			"%s: %s, gtk_hbox_new() = NULL",
+			__func__,
+			"Couldn't init main vbox"
+			);
 		goto EXITPOINT;
 	}
 
@@ -429,40 +516,90 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 	
+#if GTK_MAJOR_VERSION>=3		
+	gtk_widget_set_vexpand(recentScrolledWindow,TRUE);
+	gtk_widget_set_hexpand(recentScrolledWindow,TRUE);
+	
+	gtk_grid_attach(GTK_GRID(recentGrid),recentScrolledWindow,0,0,1,1);
+	
+	fullGrid=gtk_grid_new();
+
+#else
+	
+	if (!(fullVbox=gtk_vbox_new(FALSE,0))) {
+ 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_hbox_new() = NULL",
+			__func__,
+			"Couldn't init full_vbox"
+			);
+ 		
+ 		goto EXITPOINT;
+ 	}
 	
 	gtk_box_pack_start(GTK_BOX(recentVbox),recentScrolledWindow, TRUE,TRUE,0);
 	gtk_box_pack_end(GTK_BOX(recentVbox),recentHbox,FALSE,TRUE,0);
 	
-	if (!(fullVbox=gtk_vbox_new(FALSE,0))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create fullVbox, gtk_hbox_new() = NULL", __func__);
-		
-		goto EXITPOINT;
-	}
-
+	
 	statusBarVbox=gtk_vbox_new(FALSE,0);
+
 	if (!statusBarVbox) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create statusBarVbox, gtk_hbox_new() = NULL", __func__);
-		
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, gtk_hbox_new() = NULL",
+			__func__,
+			"Couldn't init statusbar_vbox"
+			);
 		goto EXITPOINT;
 	}
+#endif
 
+
+#if GTK_MAJOR_VERSION>=3		
+	gtk_paned_pack1(GTK_PANED(vpaned),grid,TRUE,FALSE);
+	gtk_paned_pack2(GTK_PANED(vpaned),recentGrid,TRUE,TRUE);
+#else
 	gtk_paned_pack1(GTK_PANED(vpaned),vbox,TRUE,FALSE);
 	gtk_paned_pack2(GTK_PANED(vpaned),recentVbox,TRUE,TRUE);
+#endif
 	
 	gtk_widget_show(vpaned);
 	
+	
+#if GTK_MAJOR_VERSION>=3		
+	gtk_grid_attach(GTK_GRID(fullGrid),vpaned,0,0,1,1);
+	
+	gtk_widget_show(GTK_WIDGET(fullGrid));
+	
+	if (!gPrefs.hide_statusbar) {
+		if (!init_statusbar(fullGrid,vpaned,&tempErr)) {
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s", tempErr->message,"Error initing statusbar");
+			goto EXITPOINT;
+		}
+	}
+			
+	gtk_container_add(GTK_CONTAINER(sMainWindow), fullGrid);
+
+	
+#else
 	gtk_box_pack_start(GTK_BOX(fullVbox),vpaned,TRUE,TRUE,0);
 	
 	gtk_widget_show(GTK_WIDGET(fullVbox));
 	
-	if (!init_statusbar(fullVbox,&tempErr)) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not init statusbar", tempErr->message);
-		goto EXITPOINT;
+	if (!gPrefs.hide_statusbar) {
+		if (!init_statusbar(fullVbox,vpaned,&tempErr)) {
+			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s", 
+				tempErr->message,
+				"Couldn't init statusbar"
+			);
+			goto EXITPOINT;
+		}
 	}
-	
-		
+			
 	gtk_container_add(GTK_CONTAINER(sMainWindow), fullVbox);
 
+	gtk_widget_show(fullVbox);
+	gtk_widget_show(vpaned);
+	
+#endif
 	g_signal_connect(G_OBJECT(recentTreeView), "key-press-event", G_CALLBACK(key_press_cb), recentTreeView);
 
 	gtk_window_resize(GTK_WINDOW(sMainWindow), gPrefs.width, gPrefs.height);
@@ -475,17 +612,31 @@ gboolean setup_gui(GError **err)
 	
 	// Show it all....
 			
-	gtk_widget_show(recentHbox);
+#if GTK_MAJOR_VERSION>=3
+	gtk_widget_show(recentGrid);
 		
 	if (!gPrefs.show_recent) {
-		gtk_widget_hide(recentHbox);
+		gtk_widget_hide(recentGrid);
+	} else {
+		gtk_widget_show(recentGrid);
+	}
+#else
+	gtk_widget_show(recentVbox);
+		
+	if (!gPrefs.show_recent) {
+		gtk_widget_hide(recentVbox);
 	} else {
 		gtk_widget_show(recentVbox);
 	}
+#endif
 	
 	gtk_widget_show(projectTreeView);
 	gtk_widget_show(scrolledWindow);
+#if GTK_MAJOR_VERSION>=3
+	gtk_widget_show(grid);
+#else
 	gtk_widget_show(vbox);
+#endif
 	gtk_widget_show(sMainWindow);
 	
 	resultCode = TRUE;
@@ -681,7 +832,10 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 	fixed=fix_path((gchar*)get_project_directory(),relFilePath);
 	
 	if ((command = g_strdup_printf("open:%s\n", fixed)) == NULL) {
-		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, "%s: Error formatting Scite director command, g_strdup_printf() = NULL", __func__);
+		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, g_strdup_printf() = NULL", 
+			"Error formatting SciTE command",
+			__func__);
 	}
 	else {
 		if (send_scite_command(command, &err)) {
@@ -697,7 +851,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 			
 			gchar *statusbar_text=NULL;
 			
-			statusbar_text=g_strdup_printf("Opened %s",remove_newline(get_filename_from_full_path(command)));
+			statusbar_text=g_strdup_printf(_("Opened %s"),remove_newline(get_filename_from_full_path(command)));
 			
 			set_statusbar_text(statusbar_text);
 			
@@ -708,7 +862,8 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 EXITPOINT:
 	
 	if (err != NULL) {
-		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "Could not open selected file: \n\n%s", err->message);
+		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+			_("Could not open selected file: \n\n%s"), err->message);
 		
 		gtk_dialog_run(GTK_DIALOG (dialog));
 	}
@@ -895,7 +1050,8 @@ static void popup_open_file_cb()
 EXITPOINT:
 	
 	if (err != NULL) {
-		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "Could not open selected file: \n\n%s", err->message);
+		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+			_("Could not open selected file: \n\n%s"), err->message);
 		
 		gtk_dialog_run(GTK_DIALOG (dialog));
 	}
@@ -941,7 +1097,7 @@ void update_project_is_dirty(gboolean dirty)
 	gchar *temp_string=g_new(gchar,512);
 	
 	if ((int)strlen((char*)(window_saved_title))==0) {
-		g_snprintf(window_saved_title,512,"[UNTITLED]");
+		g_snprintf(window_saved_title,512,_("[UNTITLED]"));
 	}
 	
 	if (!dirty) {
@@ -1061,7 +1217,7 @@ static void saveproject_as_menu_cb()
 	GError *err = NULL;
 	
 	if (!save_project(NULL,&err)) {
-		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "An error occurred while saving the project: %s", err->message);
+		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("An error occurred while saving the project: %s"), err->message);
 		
 		if (dialog) {
 			gtk_dialog_run(GTK_DIALOG(dialog));
@@ -1084,7 +1240,7 @@ static void saveproject_menu_cb()
 	gchar *temp_filepath=get_project_filepath();
 	
 	if (!save_project(temp_filepath,&err)) {
-		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "An error occurred while saving the project: %s", err->message);
+		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("An error occurred while saving the project: %s"), err->message);
 		
 		if (dialog) {
 			gtk_dialog_run(GTK_DIALOG(dialog));
@@ -1106,7 +1262,7 @@ static void openproject_menu_cb()
 	GError *err = NULL;
 	
 	if (!load_project(NULL, &err)) {
-		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "An error occurred while saving the project: %s", err->message);
+		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("An error occurred while opening project file: %s"), err->message);
 		
 		if (dialog) {
 			gtk_dialog_run(GTK_DIALOG(dialog));
@@ -1155,7 +1311,6 @@ gboolean key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer userData)
 		{
 			do_rename_node(TRUE);
 			return TRUE;
-			break;
 		}
 		case GDK_KEY_F5:
 		{
@@ -1166,8 +1321,6 @@ gboolean key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer userData)
 		{
 			debug_printf("key_press_cb: keyval = %d = '%c', hardware_keycode = %d\n", event->keyval, (char) event->keyval, event->hardware_keycode);
 			return FALSE;
-			
-			break;
 		}
 	}
 	
@@ -1233,7 +1386,10 @@ void edit_options_cb()
 	gchar *command=NULL;
 	
 	if ((command = g_strdup_printf("open:%s\n", prefs_filename)) == NULL) {
-		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, "%s: Error formatting Scite director command, g_strdup_printf() = NULL", __func__);
+		g_set_error(&err, APP_SCITEPROJ_ERROR, -1, 
+			"%s: %s, g_strdup_printf() = NULL",
+			"Error formatting SciTE command",
+			__func__);
 	}
 	else {
 		if (send_scite_command(command, &err)) {
@@ -1294,7 +1450,17 @@ gboolean dialog_response_is_exit(gint test)
 void recent_files_switch_visible()
 {
 	gboolean visible=FALSE;
+
+#if GTK_MAJOR_VERSION>=3
+	g_object_get(G_OBJECT(recentGrid),"visible", &visible,NULL);
 	
+	if (visible) {
+		gtk_widget_hide(recentGrid);
+		gtk_widget_grab_focus(projectTreeView);
+	} else {
+		gtk_widget_show(recentGrid);
+	}
+#else
 	g_object_get(G_OBJECT(recentVbox),"visible", &visible,NULL);
 	
 	if (visible) {
@@ -1303,4 +1469,6 @@ void recent_files_switch_visible()
 	} else {
 		gtk_widget_show(recentVbox);
 	}
+#endif
+	
 }
